@@ -30,5 +30,5 @@ setup(
     ],
     packages=['cytolysis','cytolysis.example_data'],
     package_dir={'cytolysis': 'src', 'cytolysis.example_data': 'example_data'},
-    package_data={'cytolysis': ['*.md'], 'cytolysis.example_data': ['*.txt', '*.cym']},
+    package_data={'cytolysis': ['../*.md','*.md'], 'cytolysis.example_data': ['*.txt', '*.cym']},
  )
