@@ -29,7 +29,7 @@ def get_dict_from_pile(pile,com):
     if pile is not None:
         try:
             obj = rc.get_command(pile, com)
-            prop_dict = {key: obj.value(key) for key in obj.values()}
+            prop_dict = {key: obj.vals[key] for key in obj.values()}
         except:
             print("Warning : did not understand properties for %s" %com)
     return prop_dict
