@@ -107,7 +107,7 @@ class Fiber_set(Object_set):
         except:
             rigidity=1.0
 
-        segments = get_segments(fiber)
+        segments = get_segments(fiber.points)
         seg_lengths = np.sqrt(np.sum(np.square(segments), axis=1) )
 
         if fiber.n_points>1:
@@ -127,35 +127,35 @@ class Fiber_set(Object_set):
         return plots
 
     def plot_fiber(self, fiber, *args, **kwargs):
-        p=ipv.plot(fiber[:,0], fiber[:,1], fiber[:,2], **kwargs)
+        p=ipv.plot(fiber.points[:,0], fiber.points[:,1], fiber.points[:,2], **kwargs)
         return p
 
 
 ###### A class to contain a single filament : trying to make it leaner !
 
-class Fiber(np.ndarray):
+class Fiber:
     """ Fiber
-        A class that contains a filament. Yep, a whole class for that. Derived from np.ndarray
+        A class that contains a filament. Yep, a whole class for that.
          initiated by providing a numpy array points :
          points is a column of row vectors.
          each row vector is of the format x y z C (3D) or x y C (2D)
          with C the curvature
         """
-    def __new__(cls, *args, points = __NARR__,  **kwargs):
-        return np.asarray(points).view(cls)
+    #def __new__(cls, *args, points = __NARR__,  **kwargs):
+    #    return np.asarray(points).view(cls)
 
-    def __init__(self, *args, name="fiber", id=1,
+    def __init__(self, *args, name="fiber", id=1, points = __NARR__,
                  curvatures=__NARR__, position=__NARR__, direction=__NARR__,
                  length=None, end2end=None, **kwargs):
 
         self.name = name
+        self.points = points
         self.position = position
         self.direction = direction
         self.length = length
         self.end2end = end2end
         self.id = id
-        self.n_points = self.shape[0]
-        self.name = name
+        self.n_points = self.points.shape[0]
         self.curvatures = curvatures
 
 
